==> ideaIC-173.4301.1-sources.jar: com/android/tools/idea/gradle/project/sync/setup/module/ndk/ContentRootModuleSetupStep.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.setup.module.ndk;

import com.android.tools.idea.gradle.project.sync.SyncAction;
import com.android.tools.idea.gradle.project.model.NdkModuleModel;
import com.android.tools.idea.gradle.project.sync.setup.module.NdkModuleSetupStep;
import com.intellij.openapi.externalSystem.service.project.IdeModifiableModelsProvider;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.progress.ProgressIndicator;
import com.intellij.openapi.roots.ContentEntry;
import com.intellij.openapi.roots.ModifiableRootModel;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;

import static com.android.tools.idea.gradle.project.sync.setup.module.common.ContentEntriesSetup.removeExistingContentEntries;
import static com.android.tools.idea.gradle.util.FilePaths.pathToIdeaUrl;

public class ContentRootModuleSetupStep extends NdkModuleSetupStep {
  @Override
  protected void doSetUpModule(@NotNull Module module,
                               @NotNull IdeModifiableModelsProvider ideModelsProvider,
                               @NotNull NdkModuleModel ndkModuleModel,
                               @Nullable SyncAction.ModuleModels gradleModels,
                               @Nullable ProgressIndicator indicator) {
    ModifiableRootModel moduleModel = ideModelsProvider.getModifiableRootModel(module);
    NdkContentEntriesSetup setup = new NdkContentEntriesSetup(ndkModuleModel, moduleModel);
    List<ContentEntry> contentEntries = findContentEntries(moduleModel, ndkModuleModel);
    setup.execute(contentEntries);
  }

  @Override
  protected void gradleModelNotFound(@NotNull Module module, @NotNull IdeModifiableModelsProvider ideModelsProvider) {
    ModifiableRootModel moduleModel = ideModelsProvider.getModifiableRootModel(module);
    removeExistingContentEntries(moduleModel);
  }

  @NotNull
  private static List<ContentEntry> findContentEntries(@NotNull ModifiableRootModel moduleModel,
                                                       @NotNull NdkModuleModel ndkModuleModel) {
    removeExistingContentEntries(moduleModel);
    ContentEntry contentEntry = moduleModel.addContentEntry(pathToIdeaUrl(ndkModuleModel.getRootDirPath()));
    return Collections.singletonList(contentEntry);
  }

  @Override
  @NotNull
  public String getDescription() {
    return "Source folder(s) setup";
  }

  @Override
  public boolean invokeOnBuildVariantChange() {
    return true;
  }
}

==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/gradle/project/sync/setup/module/ndk/ContentRootModuleSetupStep.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.setup.module.ndk;

import com.android.tools.idea.gradle.project.model.NdkModuleModel;
import com.android.tools.idea.gradle.project.sync.ModuleSetupContext;
import com.android.tools.idea.gradle.project.sync.setup.module.NdkModuleSetupStep;
import com.intellij.openapi.roots.ContentEntry;
import com.intellij.openapi.roots.ModifiableRootModel;
import org.jetbrains.annotations.NotNull;

import java.util.Collections;
import java.util.List;

import static com.android.tools.idea.gradle.project.sync.setup.module.common.ContentEntriesSetup.removeExistingContentEntries;
import static com.android.tools.idea.io.FilePaths.pathToIdeaUrl;

public class ContentRootModuleSetupStep extends NdkModuleSetupStep {
  @Override
  protected void doSetUpModule(@NotNull ModuleSetupContext context,
                               @NotNull NdkModuleModel ndkModuleModel) {
    ModifiableRootModel moduleModel = context.getModifiableRootModel();
    NdkContentEntriesSetup setup = new NdkContentEntriesSetup(ndkModuleModel, moduleModel);
    List<ContentEntry> contentEntries = findContentEntries(moduleModel, ndkModuleModel);
    setup.execute(contentEntries);
  }

  @NotNull
  private static List<ContentEntry> findContentEntries(@NotNull ModifiableRootModel moduleModel,
                                                       @NotNull NdkModuleModel ndkModuleModel) {
    removeExistingContentEntries(moduleModel);
    ContentEntry contentEntry = moduleModel.addContentEntry(pathToIdeaUrl(ndkModuleModel.getRootDirPath()));
    return Collections.singletonList(contentEntry);
  }

  @Override
  public boolean invokeOnBuildVariantChange() {
    return true;
  }
}
